@@ -12,7 +12,7 @@ use Moose::Util::TypeConstraints;
 use String::Formatter;
 use namespace::autoclean;
 use Try::Tiny;
-use Term::ANSIColor 2.02, qw(color colorvalid);
+use Term::ANSIColor 2.02 qw(color colorvalid);
 extends 'App::Sqitch::Command';
 use constant CAN_OUTPUT_COLOR => $^O eq 'MSWin32'
     ? try { require Win32::Console::ANSI }
@@ -22,7 +22,7 @@ BEGIN {
     $ENV{ANSI_COLORS_DISABLED} = 1 unless CAN_OUTPUT_COLOR;
 }
 
-our $VERSION = '0.92';
+our $VERSION = '0.921';
 
 my %FORMATS;
 $FORMATS{raw} = <<EOF;
